#!/bin/bash
# Author : Guth (guth@ploposor.com)
# Sources location : http://www.pldaniels.com/altermime/altermime-0.3.8.tar.gz

# program name/version
softversion='0.3.8'
softname='altermime'

# architecture/package version
arch='i486'
cpu='i686'
packageversion='52.1'

# number of parallel tasks of make
ntasks='-j2'

# parameters needed for the build process
buildir=$(pwd)
package="$softname-$softversion-$arch-$packageversion"

# prepare the build result directory
dest="$buildir/$package"
rm -rf $dest
rm -f $package.*
mkdir -p $dest
mkdir -p $dest/install
mkdir -p $dest/usr/src/$softname-$softversion
mkdir -p $dest/usr/bin

# make a slack-desc file
cat <<EOF > $dest/install/slack-desc
       |-----handy-ruler------------------------------------------------------|
altermime: A program which is used to alter your mime-encoded mailpacks
altermime:
altermime: alterMIME is a small program which is used to alter your
altermime: mime-encoded mailpacks as typically received by Inflex, Xamime and
altermime: AMaViS.
altermime: AlterMIME can:
altermime: insert disclamers
altermime: insert arbitrary X-headers
altermime: modify existing headers
altermime: remove attachements based on filename or content-type
altermime: replace attachments based on filename
EOF

# extract sources
echo "extracting ..."
srcdir="$softname-$softversion"
cd $buildir
rm -rf $srcdir
tar zxf $softname-$softversion.tar.gz || exit
cd $srcdir

# set correct permissions
chown -R root.root .
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 666 -exec chmod 644 {} \;
find . -perm 664 -exec chmod 644 {} \;

# configure package for compilation

echo "configuring ..."

mkdir -p $dest/usr/doc/$softname-$softversion

#export CFLAGS="-O2 -march=$arch -mtune=$cpu"
#export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"
destforsed=`echo $dest|sed '/\// s/\//\\\\\//g'`
sed -i "s/^\(CFLAGS=.*\)/\1  -march=$arch -mtune=$cpu/g" Makefile
sed -i "s/\/usr\/local\/bin\$/$destforsed\/usr\/bin\/$softname/g" Makefile
sed -i "s/\/usr\/local\/bin/$destforsed\/usr\/bin/g" Makefile

# compile package
make $ntasks || exit

# install package to the target directory
make install || exit

#make install DESTDIR=$dest || exit

# copy the doc files

cp -a \
 CHANGELOG INSTALL LICENCE README \
 $dest/usr/doc/$softname-$softversion

# strip executables
echo "stripping ..."
( cd $dest
   find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
   find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)

# gzip man pages and info files
echo "gzipping ..."
gzip -9 $dest/usr/man/*/*

# put the ZenWalk build and other needed files in the right directory
echo "setting perms ..."
cp -a $buildir/build-$softname.sh $dest/usr/src/$softname-$softversion
chown -R root.root $dest/usr/src/$softname-$softversion

# change files ownerships for $dest/usr/sbin
chown -R root.root $dest/usr/bin
#chown -R root.root $dest/usr/sbin



#------------------( Create The *.dep File )
echo "creating .dep ..."
cd $dest
requiredbuilder -z $dest > $buildir/$package.dep || exit
#echo -n "freetype,libart_lgpl,libpng,perl,python,zlibroot" > $buildir/$package.dep

cd $dest
makepkg -l y -c n $package.tgz || exit
mv $package.tgz $buildir

# computes the md5sum signature for the package
echo "creating .md5 ..."
cd $buildir
md5sum $package.tgz > $package.md5 || exit

if [ "$1" == "--cleanup" ]; then
  rm -rf $dest
  rm -rf $srcdir
fi

